Coverage for /home/lvcong/PythonProjects/sanic-restful/sanic_restful/__init__.py: 100%

# Coverage for /home/lvcong/PythonProjects/sanic-restful/sanic_restful/__init__.py : 100%

## 4 statements 4 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 | from sanic_restful.api import Api from sanic_restful.resource import Resource from sanic_restful.marshal import marshal_with, marshal __all__ = ['Api', 'Resource', 'marshal_with', 'marshal']